@@ -8,7 +8,7 @@
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkUnixRFont.c,v 1.20 2007/05/15 19:37:58 jenglish Exp $
+ * RCS: @(#) $Id: tkUnixRFont.c,v 1.24.2.2 2009/10/10 19:38:27 dkf Exp $
  */
 
 #include "tkUnixInt.h"
@@ -33,10 +33,8 @@ typedef struct {
     Display *display;
     int screen;
     XftDraw *ftDraw;
-    Drawable drawable;
     XftColor color;
 } UnixFtFont;
-
 
 /*
  * Package initialization:
@@ -81,14 +79,107 @@ GetFont(
 	i = 0;
     }
     if (!fontPtr->faces[i].ftFont) {
-	FcPattern *pat = FcFontRenderPrepare(0, fontPtr->pattern,
-		fontPtr->faces[i].source);
+	FcPattern *pat = FcFontRenderPrepare(0,
+	    fontPtr->pattern, fontPtr->faces[i].source);
+	XftFont *ftFont = XftFontOpenPattern(fontPtr->display, pat);
 
-	fontPtr->faces[i].ftFont = XftFontOpenPattern(fontPtr->display, pat);
+	if (!ftFont) {
+	    /*
+	     * The previous call to XftFontOpenPattern() should not fail,
+	     * but sometimes does anyway.  Usual cause appears to be
+	     * a misconfigured fontconfig installation; see [Bug 1090382].
+	     * Try a fallback:
+	     */
+	    ftFont = XftFontOpen(fontPtr->display, fontPtr->screen,
+			FC_FAMILY, FcTypeString, "sans",
+			FC_SIZE, FcTypeDouble, 12.0,
+			NULL);
+	}
+	if (!ftFont) {
+	    /*
+	     * The previous call should definitely not fail.
+	     * Impossible to proceed at this point.
+	     */
+	    Tcl_Panic("Cannot find a usable font.");
+	}
+
+	fontPtr->faces[i].ftFont = ftFont;
     }
     return fontPtr->faces[i].ftFont;
 }
 
+/*
+ *---------------------------------------------------------------------------
+ *
+ * GetTkFontAttributes --
+ * 	Fill in TkFontAttributes from an XftFont.
+ */
+
+static void
+GetTkFontAttributes(
+    XftFont *ftFont,
+    TkFontAttributes *faPtr)
+{
+    char *family = "Unknown", **familyPtr = &family;
+    int weight, slant, size, pxsize;
+    double ptsize;
+
+    (void)XftPatternGetString(ftFont->pattern, XFT_FAMILY, 0, familyPtr);
+    if (XftPatternGetDouble(ftFont->pattern, XFT_SIZE, 0,
+	    &ptsize) == XftResultMatch) {
+	size = (int)ptsize;
+    } else if (XftPatternGetInteger(ftFont->pattern, XFT_PIXEL_SIZE, 0,
+	    &pxsize) == XftResultMatch) {
+	size = -pxsize;
+    } else {
+	size = 12;
+    }
+    if (XftPatternGetInteger(ftFont->pattern, XFT_WEIGHT, 0,
+	    &weight) != XftResultMatch) {
+	weight = XFT_WEIGHT_MEDIUM;
+    }
+    if (XftPatternGetInteger(ftFont->pattern, XFT_SLANT, 0,
+	    &slant) != XftResultMatch) {
+	slant = XFT_SLANT_ROMAN;
+    }
+
+#if DEBUG_FONTSEL
+    printf("family %s size %d weight %d slant %d\n",
+	    family, size, weight, slant);
+#endif /* DEBUG_FONTSEL */
+
+    faPtr->family = Tk_GetUid(family);
+    faPtr->size = size;
+    faPtr->weight = (weight > XFT_WEIGHT_MEDIUM) ? TK_FW_BOLD : TK_FW_NORMAL;
+    faPtr->slant = (slant > XFT_SLANT_ROMAN) ? TK_FS_ITALIC : TK_FS_ROMAN;
+    faPtr->underline = 0;
+    faPtr->overstrike = 0;
+}
+
+/*
+ *---------------------------------------------------------------------------
+ *
+ * GetTkFontMetrics --
+ * 	Fill in TkFontMetrics from an XftFont.
+ */
+
+static void GetTkFontMetrics(
+    XftFont *ftFont,
+    TkFontMetrics *fmPtr)
+{
+    int spacing;
+
+    if (XftPatternGetInteger(ftFont->pattern, XFT_SPACING, 0,
+	    &spacing) != XftResultMatch) {
+	spacing = XFT_PROPORTIONAL;
+    }
+
+    fmPtr->ascent = ftFont->ascent;
+    fmPtr->descent = ftFont->descent;
+    fmPtr->maxWidth = ftFont->max_advance_width;
+    fmPtr->fixed = spacing != XFT_PROPORTIONAL;
+}
+
 /*
  *---------------------------------------------------------------------------
  *
@@ -109,15 +200,11 @@ InitFont(
     FcPattern *pattern,
     UnixFtFont *fontPtr)
 {
-    TkFontAttributes *faPtr;
-    TkFontMetrics *fmPtr;
-    char *family, **familyPtr = &family;
-    int weight, slant, spacing, i;
-    double size;
     FcFontSet *set;
     FcCharSet *charset;
     FcResult result;
     XftFont *ftFont;
+    int i;
 
     if (!fontPtr) {
 	fontPtr = (UnixFtFont *) ckalloc(sizeof(UnixFtFont));
@@ -132,7 +219,6 @@ InitFont(
 
     set = FcFontSort(0, pattern, FcTrue, NULL, &result);
     if (!set) {
-	FcPatternDestroy(pattern);
 	ckfree((char *)fontPtr);
 	return NULL;
     }
@@ -157,80 +243,60 @@ InitFont(
 	}
     }
 
-    fontPtr->font.fid = XLoadFont(Tk_Display(tkwin), "fixed");
     fontPtr->display = Tk_Display(tkwin);
     fontPtr->screen = Tk_ScreenNumber(tkwin);
     fontPtr->ftDraw = 0;
-    fontPtr->drawable = 0;
     fontPtr->color.color.red = 0;
     fontPtr->color.color.green = 0;
     fontPtr->color.color.blue = 0;
     fontPtr->color.color.alpha = 0xffff;
     fontPtr->color.pixel = 0xffffffff;
 
+    /*
+     * Fill in platform-specific fields of TkFont.
+     */
     ftFont = GetFont(fontPtr, 0);
+    fontPtr->font.fid = XLoadFont(Tk_Display(tkwin), "fixed");
+    GetTkFontAttributes(ftFont, &fontPtr->font.fa);
+    GetTkFontMetrics(ftFont, &fontPtr->font.fm);
 
     /*
-     * Build the Tk font structure
+     * Fontconfig can't report any information about the position or thickness
+     * of underlines or overstrikes. Thus, we use some defaults that are
+     * hacked around from backup defaults in tkUnixFont.c, which are in turn
+     * based on recommendations in the X manual. The comments from that file
+     * leading to these computations were:
+     *
+     *	    If the XA_UNDERLINE_POSITION property does not exist, the X manual
+     *	    recommends using half the descent.
+     *
+     *	    If the XA_UNDERLINE_THICKNESS property does not exist, the X
+     *	    manual recommends using the width of the stem on a capital letter.
+     *	    I don't know of a way to get the stem width of a letter, so guess
+     *	    and use 1/3 the width of a capital I.
+     *
+     * Note that nothing corresponding to *either* property is reported by
+     * Fontconfig at all. [Bug 1961455]
      */
 
-    if (XftPatternGetString(ftFont->pattern, XFT_FAMILY, 0,
-	    familyPtr) != XftResultMatch) {
-	family = "Unknown";
-    }
+    {
+	TkFont *fPtr = &fontPtr->font;
+	int iWidth;
 
-    if (XftPatternGetInteger(ftFont->pattern, XFT_WEIGHT, 0,
-	    &weight) != XftResultMatch) {
-	weight = XFT_WEIGHT_MEDIUM;
+	fPtr->underlinePos = fPtr->fm.descent / 2;
+	Tk_MeasureChars((Tk_Font) fPtr, "I", 1, -1, 0, &iWidth);
+	fPtr->underlineHeight = iWidth / 3;
+	if (fPtr->underlineHeight == 0) {
+	    fPtr->underlineHeight = 1;
+	}
+	if (fPtr->underlineHeight + fPtr->underlinePos > fPtr->fm.descent) {
+	    fPtr->underlineHeight = fPtr->fm.descent - fPtr->underlinePos;
+	    if (fPtr->underlineHeight == 0) {
+		fPtr->underlinePos--;
+		fPtr->underlineHeight = 1;
+	    }
+	}
     }
-    if (weight <= XFT_WEIGHT_MEDIUM) {
-	weight = TK_FW_NORMAL;
-    } else {
-	weight = TK_FW_BOLD;
-    }
-
-    if (XftPatternGetInteger(ftFont->pattern, XFT_SLANT, 0,
-	    &slant) != XftResultMatch) {
-	slant = XFT_SLANT_ROMAN;
-    }
-    if (slant <= XFT_SLANT_ROMAN) {
-	slant = TK_FS_ROMAN;
-    } else {
-	slant = TK_FS_ITALIC;
-    }
-
-    if (XftPatternGetDouble(ftFont->pattern, XFT_SIZE, 0,
-	    &size) != XftResultMatch) {
-	size = 12.0;
-    }
-
-    if (XftPatternGetInteger(ftFont->pattern, XFT_SPACING, 0,
-	    &spacing) != XftResultMatch) {
-	spacing = XFT_PROPORTIONAL;
-    }
-    if (spacing == XFT_PROPORTIONAL) {
-	spacing = 0;
-    } else {
-	spacing = 1;
-    }
-#if DEBUG_FONTSEL
-    printf("family %s size %g weight %d slant %d\n",
-	    family, size, weight, slant);
-#endif /* DEBUG_FONTSEL */
-
-    faPtr = &fontPtr->font.fa;
-    faPtr->family = family;
-    faPtr->size = (int) size;
-    faPtr->weight = weight;
-    faPtr->slant = slant;
-    faPtr->underline = 0;
-    faPtr->overstrike = 0;
-
-    fmPtr = &fontPtr->font.fm;
-    fmPtr->ascent = ftFont->ascent;
-    fmPtr->descent = ftFont->descent;
-    fmPtr->maxWidth = ftFont->max_advance_width;
-    fmPtr->fixed = spacing;
 
     return fontPtr;
 }
@@ -293,6 +359,7 @@ TkpGetNativeFont(
 
     fontPtr = InitFont(tkwin, pattern, NULL);
     if (!fontPtr) {
+	FcPatternDestroy(pattern);
 	return NULL;
     }
     return &fontPtr->font;
@@ -323,11 +390,11 @@ TkpGetFontFromAttributes(
 	XftPatternAddString(pattern, XFT_FAMILY, faPtr->family);
     }
     if (faPtr->size > 0) {
-	XftPatternAddInteger(pattern, XFT_SIZE, faPtr->size);
+	XftPatternAddDouble(pattern, XFT_SIZE, (double)faPtr->size);
     } else if (faPtr->size < 0) {
 	XftPatternAddInteger(pattern, XFT_PIXEL_SIZE, -faPtr->size);
     } else {
-	XftPatternAddInteger(pattern, XFT_SIZE, 12);
+	XftPatternAddDouble(pattern, XFT_SIZE, 12.0);
     }
     switch (faPtr->weight) {
     case TK_FW_NORMAL:
@@ -358,9 +425,25 @@ TkpGetFontFromAttributes(
 	FinishedWithFont(fontPtr);
     }
     fontPtr = InitFont(tkwin, pattern, fontPtr);
+
+    /*
+     * Hack to work around issues with weird issues with Xft/Xrender
+     * connection. For details, see comp.lang.tcl thread starting from
+     * <adcc99ed-c73e-4efc-bb5d-e57a57a051e8@l35g2000pra.googlegroups.com>
+     */
+
     if (!fontPtr) {
+	XftPatternAddBool(pattern, XFT_RENDER, FcFalse);
+	fontPtr = InitFont(tkwin, pattern, fontPtr);
+    }
+
+    if (!fontPtr) {
+	FcPatternDestroy(pattern);
 	return NULL;
     }
+
+    fontPtr->font.fa.underline = faPtr->underline;
+    fontPtr->font.fa.overstrike = faPtr->overstrike;
     return &fontPtr->font;
 }
 
@@ -394,10 +477,9 @@ TkpGetFontFamilies(
     Tcl_Interp *interp,		/* Interp to hold result. */
     Tk_Window tkwin)		/* For display to query. */
 {
-    Tcl_Obj *resultPtr, *strPtr;
+    Tcl_Obj *resultPtr;
     XftFontSet *list;
     int i;
-    char *family, **familyPtr = &family;
 
     resultPtr = Tcl_NewListObj(0, NULL);
 
@@ -405,9 +487,11 @@ TkpGetFontFamilies(
 		(char*)0,		/* pattern elements */
 		XFT_FAMILY, (char*)0);	/* fields */
     for (i = 0; i < list->nfont; i++) {
-	if (XftPatternGetString(list->fonts[i], XFT_FAMILY, 0,
-		familyPtr) == XftResultMatch) {
-	    strPtr = Tcl_NewStringObj(Tk_GetUid(family), -1);
+	char *family, **familyPtr = &family;
+	if (XftPatternGetString(list->fonts[i], XFT_FAMILY, 0, familyPtr)
+		== XftResultMatch)
+	{
+	    Tcl_Obj *strPtr = Tcl_NewStringObj(family, -1);
 	    Tcl_ListObjAppendElement(NULL, resultPtr, strPtr);
 	}
     }
@@ -437,9 +521,9 @@ TkpGetSubFonts(
     Tcl_Obj *objv[3], *listPtr, *resultPtr;
     UnixFtFont *fontPtr = (UnixFtFont *) tkfont;
     FcPattern *pattern;
-    char *family, **familyPtr = &family;
-    char *foundry, **foundryPtr = &foundry;
-    char *encoding, **encodingPtr = &encoding;
+    char *family = "Unknown", **familyPtr = &family;
+    char *foundry = "Unknown", **foundryPtr = &foundry;
+    char *encoding = "Unknown", **encodingPtr = &encoding;
     int i;
 
     resultPtr = Tcl_NewListObj(0, NULL);
@@ -448,18 +532,9 @@ TkpGetSubFonts(
  	pattern = FcFontRenderPrepare(0, fontPtr->pattern,
 		fontPtr->faces[i].source);
 
-	if (XftPatternGetString(pattern, XFT_FAMILY, 0,
-		familyPtr) != XftResultMatch) {
-	    family = "Unknown";
-	}
-	if (XftPatternGetString(pattern, XFT_FOUNDRY, 0,
-		foundryPtr) != XftResultMatch) {
-	    foundry = "Unknown";
-	}
-	if (XftPatternGetString(pattern, XFT_ENCODING, 0,
-		encodingPtr) != XftResultMatch) {
-	    encoding = "Unknown";
-	}
+	XftPatternGetString(pattern, XFT_FAMILY, 0, familyPtr);
+	XftPatternGetString(pattern, XFT_FOUNDRY, 0, foundryPtr);
+	XftPatternGetString(pattern, XFT_ENCODING, 0, encodingPtr);
 	objv[0] = Tcl_NewStringObj(family, -1);
 	objv[1] = Tcl_NewStringObj(foundry, -1);
 	objv[2] = Tcl_NewStringObj(encoding, -1);
@@ -477,12 +552,6 @@ TkpGetSubFonts(
  *	Retrieve the font attributes of the actual font used to render a given
  *	character.
  *
- * Results:
- *	None.
- *
- * Side effects:
- *	The font attributes are stored in *faPtr.
- *
  *----------------------------------------------------------------------
  */
 
@@ -497,34 +566,10 @@ TkpGetFontAttrsForChar(
 				/* Structure describing the logical font */
     FcChar32 ucs4 = (FcChar32) c;
 				/* UCS-4 character to map */
-    XftFont *xftFontPtr = GetFont(fontPtr, ucs4);
+    XftFont *ftFont = GetFont(fontPtr, ucs4);
 				/* Actual font used to render the character */
-    const char *family;		/* Font family name */
-    const char **familyPtr = &family;
-    double size;		/* Font size */
-    int weight;			/* Font weight */
-    int slant;			/* Font slant */
 
-    if (XftPatternGetString(xftFontPtr->pattern, XFT_FAMILY, 0,
-	    familyPtr) != XftResultMatch) {
-	family = "Unknown";
-    }
-    if (XftPatternGetDouble(xftFontPtr->pattern, XFT_SIZE, 0,
-	    &size) != XftResultMatch) {
-	size = 12.0;
-    }
-    if (XftPatternGetInteger(xftFontPtr->pattern, XFT_WEIGHT, 0,
-	    &weight) != XftResultMatch) {
-	weight = XFT_WEIGHT_MEDIUM;
-    }
-    if (XftPatternGetInteger(xftFontPtr->pattern, XFT_SLANT, 0,
-	    &slant) != XftResultMatch) {
-	slant = XFT_SLANT_ROMAN;
-    }
-    faPtr->family = Tk_GetUid(family);
-    faPtr->size = (int) size;
-    faPtr->weight = (weight > XFT_WEIGHT_MEDIUM) ? TK_FW_BOLD : TK_FW_NORMAL;
-    faPtr->slant = (slant > XFT_SLANT_ROMAN) ? TK_FS_ITALIC : TK_FS_ROMAN;
+    GetTkFontAttributes(ftFont, faPtr);
     faPtr->underline = fontPtr->font.fa.underline;
     faPtr->overstrike = fontPtr->font.fa.overstrike;
 }
@@ -666,7 +711,7 @@ Tk_DrawChars(
     UnixFtFont *fontPtr = (UnixFtFont *) tkfont;
     XGCValues values;
     XColor xcolor;
-    int clen, nspec;
+    int clen, nspec, xStart = x;
     XftGlyphFontSpec specs[NUM_SPEC];
     XGlyphInfo metrics;
 
@@ -677,13 +722,11 @@ Tk_DrawChars(
 	fontPtr->ftDraw = XftDrawCreate(display, drawable,
 		DefaultVisual(display, fontPtr->screen),
 		DefaultColormap(display, fontPtr->screen));
-	fontPtr->drawable = drawable;
     } else {
 	Tk_ErrorHandler handler = Tk_CreateErrorHandler(display, -1, -1, -1,
 		NULL, (ClientData) NULL);
 
 	XftDrawChange(fontPtr->ftDraw, drawable);
-	fontPtr->drawable = drawable;
 	Tk_DeleteErrorHandler(handler);
     }
     XGetGCValues(display, gc, GCForeground, &values);
@@ -708,7 +751,7 @@ Tk_DrawChars(
 	     * This should not happen, but it can.
 	     */
 
-	    return;
+	    goto doUnderlineStrikeout;
 	}
 	source += clen;
 	numBytes -= clen;
@@ -734,4 +777,17 @@ Tk_DrawChars(
     if (nspec) {
 	XftDrawGlyphFontSpec(fontPtr->ftDraw, &fontPtr->color, specs, nspec);
     }
+
+  doUnderlineStrikeout:
+    if (fontPtr->font.fa.underline != 0) {
+	XFillRectangle(display, drawable, gc, xStart,
+		y + fontPtr->font.underlinePos, (unsigned) (x - xStart),
+		(unsigned) fontPtr->font.underlineHeight);
+    }
+    if (fontPtr->font.fa.overstrike != 0) {
+	y -= fontPtr->font.fm.descent + (fontPtr->font.fm.ascent) / 10;
+	XFillRectangle(display, drawable, gc, xStart, y,
+		(unsigned) (x - xStart),
+		(unsigned) fontPtr->font.underlineHeight);
+    }
 }
